==> java-gnome-4.0.4.tar.bz2: java-gnome-4.0.4/src/bindings/org/gnome/gtk/FileChooserWidget.java <==
/*
 * FileChooserWidget.java
 *
 * Copyright (c) 2007 Operational Dynamics Consulting Pty Ltd
 *
 * The code in this file, and the library it is a part of, are made available
 * to you by the authors under the terms of the "GNU General Public Licence,
 * version 2" plus the "Classpath Exception" (you may link to this code as a
 * library into other programs provided you don't make a derivation of it).
 * See the LICENCE file for the terms governing usage and redistribution.
 */
package org.gnome.gtk;

import java.net.URI;

/*
 * FIXME this is a placeholder stub for what will become the public API for
 * this type. Replace this comment with appropriate javadoc including author
 * and since tags. Note that the class may need to be made abstract, implement
 * interfaces, or even have its parent changed. No API stability guarantees
 * are made about this class until it has been reviewed by a hacker and this
 * comment has been replaced.
 */
public class FileChooserWidget extends VBox implements FileChooser
{
    protected FileChooserWidget(long pointer) {
        super(pointer);
    }

    public String getCurrentFolder() {
        // TODO method stub to satisfy interface to permit compilation.
        return null;
    }

    public boolean setCurrentFolder(String directory) {
        // TODO method stub to satisfy interface to permit compilation.
        return false;
    }

    public String getFilename() {
        // TODO method stub to satisfy interface to permit compilation.
        return null;
    }

    public void setAction(FileChooserAction action) {
    // TODO method stub to satisfy interface to permit compilation.
    }

    public FileChooserAction getAction() {
        // TODO method stub to satisfy interface to permit compilation.
        return null;
    }

    public URI getURI() {
        // TODO method stub to satisfy interface to permit compilation.
        return null;
    }

    public void connect(FileChooser.SELECTION_CHANGED handler) {
    // TODO method stub to satisfy interface to permit compilation.
    }
}

==> java-gnome-4.0.10-rc1.tar.bz2: java-gnome-4.0.10-rc1/src/bindings/org/gnome/gtk/FileChooserWidget.java <==
/*
 * FileChooserWidget.java
 *
 * Copyright (c) 2007 Operational Dynamics Consulting Pty Ltd
 *
 * The code in this file, and the library it is a part of, are made available
 * to you by the authors under the terms of the "GNU General Public Licence,
 * version 2" plus the "Classpath Exception" (you may link to this code as a
 * library into other programs provided you don't make a derivation of it).
 * See the LICENCE file for the terms governing usage and redistribution.
 */
package org.gnome.gtk;

import java.net.URI;

/*
 * FIXME this is a placeholder stub for what will become the public API for
 * this type. Replace this comment with appropriate javadoc including author
 * and since tags. Note that the class may need to be made abstract, implement
 * interfaces, or even have its parent changed. No API stability guarantees
 * are made about this class until it has been reviewed by a hacker and this
 * comment has been replaced.
 */
public class FileChooserWidget extends VBox implements FileChooser
{
    protected FileChooserWidget(long pointer) {
        super(pointer);
    }

    public String getCurrentFolder() {
        // TODO method stub to satisfy interface to permit compilation.
        return null;
    }

    public boolean setCurrentFolder(String directory) {
        // TODO method stub to satisfy interface to permit compilation.
        return false;
    }

    public String getFilename() {
        // TODO method stub to satisfy interface to permit compilation.
        return null;
    }

    public void setAction(FileChooserAction action) {
    // TODO method stub to satisfy interface to permit compilation.
    }

    public FileChooserAction getAction() {
        // TODO method stub to satisfy interface to permit compilation.
        return null;
    }

    public URI getURI() {
        // TODO method stub to satisfy interface to permit compilation.
        return null;
    }

    public boolean setFilename(String filename) {
        // TODO method stub to satisfy interface to permit compilation.
        return false;
    }
}
